##################################################################################
#
#    Copyright (C) 2006 Utah State University, All rights reserved.
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
##################################################################################

__author__  = '''Brent Lambert, David Ray, Jon Thomas'''
__docformat__ = 'plaintext'
__version__   = '$ Revision 0.0 $'[11:-2]

from zope.interface import Interface
from zope.annotation.interfaces import IAnnotatable

class ILicensable(IAnnotatable):
    """ Marker interface """

class ILicense(Interface):
    """ License interface """

    def getRightsLicense():
        """ Get the license """
        
    def setRightsLicense(ldata):
        """ Set the license """

    def getRightsHolder():
        """ Get the contents of the DC.rightsHolder field. """

    def setRightsHolder(rhdata):
        """ Set the DC.rightsHolder field. """

        



##################################################################################
#    Copyright (C) 2004-2007 Utah State University, All rights reserved.          
#                                                                                 
#    This program is free software; you can redistribute it and/or modify         
#    it under the terms of the GNU General Public License as published by         
#    the Free Software Foundation; either version 2 of the License, or            
#    (at your option) any later version.                                          
#                                                                                 
#    This program is distributed in the hope that it will be useful,              
#    but WITHOUT ANY WARRANTY; without even the implied warranty of               
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                
#    GNU General Public License for more details.                                 
#                                                                                 
#    You should have received a copy of the GNU General Public License            
#    along with this program; if not, write to the Free Software                  
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA    
#                                                                                 
##################################################################################

__author__ = 'Brent Lambert, David Ray, Jon Thomas'
__docformat__ = 'restructuredtext'
__version__ = "$Revision: 1 $"[11:-2]

from zope.app.form.browser import RadioWidget
from zope.app.form.browser.widget import SimpleInputWidget

class LicenseWidget(RadioWidget):
    """ Widget for displaying license options. """

    def __init__(self, field, request):
        """ Initialize the widget. """
        super(LicenseWidget, self).__init__(field, 
                                            field.vocabulary, 
                                            request)
        
    def renderItem(self, index, text, value, name, cssClass):
        if 'Creative Commons License' == value:
            self.request['index'] = index
            self.request['text'] = text
            self.request['value'] = value
            self.request['name'] = name
            self.request['cssClass'] = cssClass
            return self.context.context.context.restrictedTraverse('@@cc_license_widget')()
        else:
            return super(LicenseWidget, self).renderItem(index, text, value, name, cssClass)

    def renderSelectedItem(self, index, text, value, name, cssClass):
        if 'Creative Commons License' == value:
            self.request['index'] = index
            self.request['text'] = text
            self.request['value'] = value
            self.request['name'] = name
            self.request['cssClass'] = cssClass
            self.request['checked'] = True
            return self.context.context.context.restrictedTraverse('@@cc_license_widget')()
        else:
            return super(LicenseWidget, self).renderSelectedItem(index, text, value, name, cssClass)

    



from Products.CMFPlone import MigrationTool
try:
    from Products.contentmigration.migrator import InlineFieldActionMigrator, BaseInlineMigrator
    from Products.contentmigration.walker import CustomQueryWalker
    haveContentMigrations = True
except ImportError:
    haveContentMigrations = False

import types

from StringIO import StringIO
from Products.CMFCore.utils import getToolByName
from Products.Archetypes import transaction
from Products.Archetypes.BaseUnit import BaseUnit
from Products.CMFPlone.utils import safe_hasattr

from collective.contentlicensing.tool import ContentLicensingTool
from Acquisition import aq_base
from collective.contentlicensing.Extensions import Install


def GenericToUnported (self, out):
    """ Change Jurisdiction to valid attribute
    """
    print >> out, "Changing Jurisdiction from Generic to Unported"
    if self.portal_contentlicensing.Jurisdiction == 'Generic':
        self.portal_contentlicensing._updateProperty('Jurisdiction','Unported')

def migrate(self):
    """Run migrations
    """
    out = StringIO()
    print >> out, "Starting Content Licensing Migration"
    GenericToUnported(self, out)
    print >> out, "Content Licensing Migration Completed"
    return out.getvalue()





##################################################################################
#    Copyright (C) 2006-2007 Utah State University, All rights reserved.          
#                                                                                 
#    This program is free software; you can redistribute it and/or modify         
#    it under the terms of the GNU General Public License as published by         
#    the Free Software Foundation; either version 2 of the License, or            
#    (at your option) any later version.                                          
#                                                                                 
#    This program is distributed in the hope that it will be useful,              
#    but WITHOUT ANY WARRANTY; without even the implied warranty of               
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                
#    GNU General Public License for more details.                                 
#                                                                                 
#    You should have received a copy of the GNU General Public License            
#    along with this program; if not, write to the Free Software                  
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA    
#                                                                                 
##################################################################################

__author__ = 'Brent Lambert, David Ray, Jon Thomas'
__docformat__ = 'restructuredtext'
__version__ = "$Revision: 1 $"[11:-2]


from OFS.SimpleItem import SimpleItem
from zope.interface import implements
from interfaces import IContentLicensingUtility
from collective.contentlicensing.DublinCoreExtensions.interfaces import ILicensable, ILicense


cc_license_rdf = {'by':
                      {
                          'requires':['http://web.resource.org/cc/Attribution',
                                      'http://web.resource.org/cc/Notice'],
                          'permits':['http://web.resource.org/cc/Reproduction',
                                     'http://web.resource.org/cc/Distribution',
                                     'http://web.resource.org/cc/DerivativeWorks'],
                          'prohibits':[],
                      },
                  'by-nd':
                      {
                          'requires':['http://web.resource.org/cc/Attribution',
                                      'http://web.resource.org/cc/Notice'],
                          'permits':['http://web.resource.org/cc/Reproduction',
                                     'http://web.resource.org/cc/Distribution'],
                          'prohibits':[],
                      },
                  'by-nc-nd':
                      {
                          'requires':['http://web.resource.org/cc/Attribution',
                                      'http://web.resource.org/cc/Notice'],
                          'permits':['http://web.resource.org/cc/Reproduction',
                                     'http://web.resource.org/cc/Distribution'],
                          'prohibits':['http://web.resource.org/cc/CommercialUse'],
                      },
                  'by-nc':
                      {
                          'requires':['http://web.resource.org/cc/Attribution',
                                      'http://web.resource.org/cc/Notice'],
                          'permits':['http://web.resource.org/cc/Reproduction',
                                     'http://web.resource.org/cc/Distribution',
                                     'http://web.resource.org/cc/DerivativeWorks'],
                          'prohibits':['http://web.resource.org/cc/CommercialUse'],
                      },
                  'by-nc-sa':
                      {
                          'requires':['http://web.resource.org/cc/Attribution',
                                      'http://web.resource.org/cc/ShareAlike',
                                      'http://web.resource.org/cc/Notice'],
                          'permits':['http://web.resource.org/cc/Reproduction',
                                     'http://web.resource.org/cc/Distribution',
                                     'http://web.resource.org/cc/DerivativeWorks'],
                          'prohibits':['http://web.resource.org/cc/CommercialUse'],
                      },
                  'by-sa':
                      {
                          'requires':['http://web.resource.org/cc/Attribution',
                                      'http://web.resource.org/cc/ShareAlike',
                                      'http://web.resource.org/cc/Notice'],
                          'permits':['http://web.resource.org/cc/Reproduction',
                                     'http://web.resource.org/cc/Distribution',
                                     'http://web.resource.org/cc/DerivativeWorks'],
                          'prohibits':[],
                      },
                  'publicdomain':
                      {
                          'requires':[],
                          'permits':['http://web.resource.org/cc/Reproduction',
                                     'http://web.resource.org/cc/Distribution',
                                     'http://web.resource.org/cc/DerivativeWorks'],
                          'prohibits':[],
                      },
                  }


class ContentLicensingUtility(SimpleItem):
    """ Content Licensing Utility """

    implements(IContentLicensingUtility)

    def getLicenses(self, request):
        """ return titles and ids for the supported licenses. """
        props = request.portal_url.portal_properties.content_licensing_properties
        licenses = [props.license_siteDefault]
        for x in props.AvailableLicenses:
            licenses.append(getattr(props, x))
        licenses.append(props.license_other)
        return licenses


    def getSupportedLicenses(self, request):
        """ Return titles and ids fo the supported licenses for the configlet. """
        props = request.portal_url.portal_properties.content_licensing_properties
        return [[x, getattr(props, x)[0], getattr(props, x)[1]] for x in props.SupportedLicenses]
            

    def getAvailableLicenses(self, request):
        """ return titles and ids for the supported licenses """
        props = request.portal_url.portal_properties.content_licensing_properties
        return [x for x in props.AvailableLicenses]


    def getLicenseByTitle(self, request, title):
        """ Return a license based on its title. """
        props = request.portal_url.portal_properties.content_licensing_properties

        if 'Site Default' == title:
            return props.license_siteDefault
        elif 'Other' == title:
            return props.license_other
        else:
            for x in props.SupportedLicenses:
                sl = getattr(props, x)
                if sl and sl[0] == title:
                    return sl
            return None


    def getLicenseFromObject(self, obj):
        """ Get the copyright license for an object. """
        if ILicensable.providedBy(obj):
            license = ILicense(obj)
            return license.getRightsLicense()
        else:
            return None


    def getHolderFromObject(self, obj):
        """ Get the copyright holder for an object. """
        if ILicensable.providedBy(obj):
            license = ILicense(obj)
            return license.getRightsHolder()
        else:
            return None

    def getLicenseAndHolderFromObject(self, obj):
        """ Get the copyright holder and license from an object. """
        if ILicensable.providedBy(obj):
            license = ILicense(obj)
            return license.getRightsHolder(), license.getRightsLicense()
        else:
            return None


    def setLicense(self, obj, license):
        """ Set a license using the Dublin Core Annotations interface. """
        props = obj.portal_url.portal_properties.content_licensing_properties
        if getattr(obj.REQUEST, 'copyright_holder', None):
            license.setRightsHolder(obj.REQUEST['copyright_holder'])
        if getattr(obj.REQUEST, 'license', None):
            newLicense = obj.REQUEST['license']
            if 'Creative Commons License' == newLicense:
                license.setRightsLicense(['Creative Commons License',
                                          obj.REQUEST['license_cc_name'],
                                          obj.REQUEST['license_cc_url'],
                                          obj.REQUEST['license_cc_button']])
            elif 'Other' == newLicense:
                license.setRightsLicense(['Other',
                                          obj.REQUEST['license_other_name'],
                                          obj.REQUEST['license_other_url'],
                                          'None'])
            elif 'Site Default' == newLicense:
                license.setRightsLicense(props.license_siteDefault)
            else:
                nl = self.getLicenseByTitle(obj, newLicense)
                license.setRightsLicense(nl)


    def getDefaultSiteLicense(self, request):
        """ Get the default site license """
        props = request.portal_url.portal_properties.content_licensing_properties
        return props.DefaultSiteLicense


    def getSiteDefaultLicenseByLine(self, request):
        """ Get the site default for a copyright byline. """
        props = request.portal_url.portal_properties.content_licensing_properties
        copyright = props.DefaultSiteCopyright
        holder = props.DefaultSiteCopyrightHolder
        license = props.DefaultSiteLicense
        license_name = license[1]
        if not license_name or 'None' == license_name:
            license_name = ''
        if 'Creative Commons License' == license[0]:
            license_name = license[0]
        license_url = license[2]
        if not license_url or 'None' == license_url:
            license_url = ''
        license_button = license[3]
        if not license_button or 'None' == license_button:
            license_button = ''
        return copyright, holder, license_name, license_url, license_button


    def isLicensable(self, obj):
        """ Is an object licensable? """
        return ILicensable.providedBy(obj)


    def setRightsLicense(self, obj, newLicense):
        """ Set the Dublin Core Extension field. """
        if self.isLicensable(obj):
            license = ILicense(obj)
            license.setRightsLicense(newLicense)


    def setRightsHolder(self, obj, holder):
        """ Set the Dublin Core Extension RightsHolder field. """
        if self.isLicensable(obj):
            license = ILicense(obj)
            license.setRightsHolder(holder)


    def listSupportedJurisdictions(self, request):
        """ Return a list of supported jurisdiction codes. """
        props = request.portal_url.portal_properties.content_licensing_properties
        return [(x, allowedJurisdictions[x]) for x in props.jurisdiction_options]
               

    def getJurisdictionCode(self, request):
        """ Return the current jurisdiction code. """
        props = request.portal_url.portal_properties.content_licensing_properties
        juris_code = props.Jurisdiction.split(',')[0]
        if juris_code == 'Unported':
            juris_code = ''
        return juris_code


    def hasCCLicenseInfo(self, licenseId):
        """ Check to see if we have a particular CC license. """
        return cc_license_rdf.has_key(licenseId)


    def getCCLicenseInfo(self, licenseId):
        """ Return the CC license info for a CC license. """
        return cc_license_rdf[licenseId]

    def setObjLicense(self, obj):
        """ Set a license using the object """
        license = ILicense(obj)
        self.setLicense(obj, license)
        



##################################################################################
#
#    Copyright (C) 2006 Utah State University, All rights reserved.
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
##################################################################################

__author__  = '''Brent Lambert, David Ray, Jon Thomas'''
__docformat__ = 'plaintext'
__version__   = '$ Revision 0.0 $'[11:-2]

from zope.interface import implements
from collective.contentlicensing.DublinCoreExtensions.interfaces import ILicense
from zope.annotation.interfaces import IAnnotations


RIGHTSLICENSE_KEY = 'DublinCoreExtensions.Rights.License'
RIGHTSHOLDER_KEY = 'DublinCoreExtensions.RightsHolder'

class License(object):
    """
        This class adds two Dublin Core Fields to content for storing the copyright
        license, and the holder of the copyright
    """
    implements(ILicense)

    def __init__(self, context):
        self.context = context
        self.annotations = IAnnotations(context)
        rightsLicense = self.annotations.get(RIGHTSLICENSE_KEY, None)
        if rightsLicense is None:
            self.annotations[RIGHTSLICENSE_KEY] = ['Site Default', 'None', 'None', 'None']
        rightsHolder = self.annotations.get(RIGHTSHOLDER_KEY, None)
        if rightsHolder is None:
            self.annotations[RIGHTSHOLDER_KEY] = '(site default)'

    def getRightsLicense(self):
        """ Get the contents of the DC.rights.license field. """
        return self.annotations[RIGHTSLICENSE_KEY]

    def setRightsLicense(self, ldata):
        """ Set the DC.rights.license field. """
        self.annotations[RIGHTSLICENSE_KEY] = ldata

    def getRightsHolder(self):
        """ Get the contents of the DC.rightsHolder field. """
        return self.annotations[RIGHTSHOLDER_KEY]

    def setRightsHolder(self, rhdata):
        """ Set the DC.rightsHolder field. """
        self.annotations[RIGHTSHOLDER_KEY] = rhdata

    license = property(fget=getRightsLicense, fset=setRightsLicense)



from Products.Five.browser import BrowserView
from zope.component import getAdapter
from contentlicensingprefs import IContentLicensingPrefsForm

class CCWidgetView(BrowserView):
    """ CC Widget view class """

    def __init__(self, context, request):
        self.context = context
        self.request = request
        self.prefs = getAdapter(context, IContentLicensingPrefsForm)

    def getJurisdiction(self):
        juris = self.prefs.jurisdiction
        juris_code = juris.split(',')[0]
        if juris_code == 'Unported':
            juris_code = ''
        return juris_code
        
    def getCCLicenseInfo(self):
        return self.prefs.getCCLicense()

    def getFormId(self):
        return '%s.%d' %(self.request['name'], self.request['index'])

    def isChecked(self):
        if self.request.has_key('checked'):
            return True
        return False



##################################################################################
#
#    Copyright (C) 2006 Utah State University, All rights reserved.
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
##################################################################################

__author__  = '''Brent Lambert, David Ray, Jon Thomas'''
__docformat__ = 'plaintext'
__version__   = '$ Revision 0.0 $'[11:-2]

from Products.Five.browser import BrowserView
from zope.component import getUtility
from zope.interface import implements
from collective.contentlicensing.utilities.interfaces import IContentLicensingUtility
from collective.contentlicensing.browser.contentlicensingprefs import IContentLicensingPrefsForm
from Products.CMFPlone.utils import getToolByName
from urlparse import urlsplit
from xml.dom import minidom
from string import split, find
import urllib
import datetime

def unicode_sanitize(text):
    """
    Intended to be used to correct the inconsistency of plone when you call
    methods such as Title or Publisher which should ALLWAYS return a unicode
    object if the output is text.
    """
    if isinstance(text,list):
        sanit_list = []
        for item in text:
            if isinstance(item, str):
                sanit_list += item.decode('utf-8')
            else:
                sanit_list += item
        text = sanit_list          
    elif isinstance(text, str):
        text = text.decode('utf-8')
    return text


class CopyrightBylineView(BrowserView):
    """ Render the copyright byline """

    def __init__(self, context, request):
        self.context = context
        self.request = request
        self.props = self.context.portal_url.portal_properties.content_licensing_properties
        self.clutil = getUtility(IContentLicensingUtility)

    def getLicenseByline(self):
        """ Get the license byline fields for an object. """

        copyright = self.context.Rights()
        if not copyright:
            copyright = self.props.DefaultSiteCopyright
        holder, license = self.clutil.getLicenseAndHolderFromObject(self.context)
        if '(site default)' == holder:
            holder = self.props.DefaultSiteCopyrightHolder
        if 'Site Default' == license[0]:
            license = self.props.DefaultSiteLicense
        license_name = license[0]
        if not license_name or 'None' == license_name:
            license_name = ''
        if 'Creative Commons License' == license[0]:
            license_name = license[0]
        license_url = license[2]
        if not license_url or 'None' == license_url:
            license_url = ''
        license_button = license[3]
        if not license_button or 'None' == license_button:
            license_button = ''
        from Products.CMFCore.utils import getToolByName
        ts = getToolByName(self.context, 'translation_service')
        return copyright, ts.translate(holder), license_name, license_url, license_button

    def getCitationInfo(self):
        """ Gets the citation information """

        # Title
        title = self.context.title

        # Creators
        creator = ''
        index = 1
        
        names = [name.strip() for name in self.context.Creators()]
        
        for cr in names:
            inits = ''
            crs = []

            crs = cr.split(' ')
            
            for part in crs[:-1]:
                inits += ' ' + part[0] + '.'   
                
            creator += crs[-1]
            if inits:
                creator += "," + inits
            creator += ', '
            index += 1
            
        if creator:
            creator = creator[:-2]
            if creator:
                if creator[-1] != '.':
                    creator += '.'
         
        id = self.context.getId()
        portal_url = getToolByName(self.context, 'portal_url')
        portal_name = portal_url.getPortalObject().title
        create_date = self.context.creation_date.strftime('%Y, %B %d')
        url = self.context.absolute_url()
        date = datetime.date.today().strftime('%B %d, %Y')
        
        if creator:
            prompt_text = "%s (%s). %s. Retrieved %s, from %s Web site: %s." %(unicode_sanitize(creator),create_date,unicode_sanitize(title),date,unicode_sanitize(portal_name),url)
        else:
            prompt_text = "%s. (%s). Retrieved %s, from %s Web site: %s." %(unicode_sanitize(title),create_date,date,unicode_sanitize(portal_name),url)

        return prompt_text.replace('\'','\\\'').replace('\"','\\\'')



class ExtendedCopyrightFieldForm(BrowserView):
    """ Render the additional copyright fields in the metadata form. """
    def __init__(self, context, request):
        self.context = context
        self.request = request
        self.clutil = getUtility(IContentLicensingUtility)
        self.license = None
        self.holder = None
        results = self.clutil.getLicenseAndHolderFromObject(self.context)
        if results:
            self.holder = results[0]
            self.license = results[1]
            
    def isLicensable(self):
        """ Is the object licensable """
        return self.clutil.isLicensable(self.context)

    def getLicenses(self):
        """ Get list of supported licenses. """
        return self.clutil.getLicenses(self.context)

    def getLicense(self):
        """ Get the copyright license from the object. """
        return self.license

    def getHolder(self):
        """ Get the copyright license holder. """
        return self.holder

    def getJurisdictionCode(self):
        """ Get the Creative Commons jurisdiction code. """
        return self.clutil.getJurisdictionCode(self.context)

    def getSiteDefaultCCLicense(self, item):
        """ Get the Default Site Creative Commons License for prefs panel  """

        pass


    def getDefaultCCLicense(self, item):
        """ If the item already has a creative commons license, return it """
        if self.license and 'Creative Commons License' == self.license[0]:
            return self.license
        else:
            return item

    def getDefaultOtherLicenseName(self):
        """ Get other license name """
        if self.license and 'Other' == self.license[0]:
            return self.license[0]
        else:
            return ''

    def getDefaultOtherLicenseUrl(self):
        """ Get other license URL """
        if self.license and 'Other' == self.license[0]:
            return self.license[0]
        else:
            return ''

    def getDefaultOtherLicenseButton(self):
        """ Get other license URL """
        if self.license and 'Other' == self.license[0]:
            return self.license[0]
        else:
            return 'default_other.gif'

    def getLicenseAndHolderFromObject(self, obj):
        """ Get the license and copyright holder from the object """
        return self.clutil.getLicenseAndHolderFromObject(self.context)        

    def getDefaultSiteLicense(self, request):
        """ Get the default site license  """
        return self.clutil.getDefaultSiteLicense(request)

    def getLicenseTitle(self, request):
        """ Returns the license name. For creative commons licenses, it explicitly appends the CC license type  """
	ts = getToolByName(self.context,'translation_service')
        license = self.clutil.getDefaultSiteLicense(request)
        if license[0] == 'Creative Commons License':
            return ts.translate(license[0]) + ' :: ' + license[1]
        else:
            return ts.translate(license[0])

class FrontpageCopyrightBylineView(BrowserView):
    """ Render the default site copyright byline """

    def __init__(self, context, request):
        self.context = context
        self.request = request
        self.props = self.context.portal_url.portal_properties.content_licensing_properties
        self.clutil = getUtility(IContentLicensingUtility)

    def getLicenseByline(self):
        """ Get the license byline fields for an object. """

        copyright = self.context.Rights()
        copyright = self.props.DefaultSiteCopyright
        holder = self.props.DefaultSiteCopyrightHolder
        license = self.props.DefaultSiteLicense
        license_name = license[1]
        if not license_name or 'None' == license_name:
            license_name = ''
        if 'Creative Commons License' == license[0]:
            license_name = license[0]
        license_url = license[2]
        if not license_url or 'None' == license_url:
            license_url = ''
        license_button = license[3]
        if not license_button or 'None' == license_button:
            license_button = ''
        return copyright, holder, license_name, license_url, license_button        

class RDFMetadataView(BrowserView):
    """ Express Dublin Core As Rdf  """

    def __init__(self, context, request):
        self.context = context
        self.request = request
        self.document = minidom.Document()
        self.props = self.context.portal_url.portal_properties.content_licensing_properties
        self.clutil = getUtility(IContentLicensingUtility)
        self.holder, self.license = self.clutil.getLicenseAndHolderFromObject(context)        

    def __call__(self):
        self.request.response.setHeader('Content-Type', 'application/rdf+xml')
        return self.writeRDF()

    def writeRDF(self):
        """ Write RDF metadata """
        if 'Creative Commons License' == self.license[0] or ('Creative Commons License' == self.props.DefaultSiteLicense[0] and 'Site Default' == self.license[0]):
            if self.license[0] == 'Site Default':
                self.license = self.props.DefaultSiteLicense
            data = self.getCCLicenseRDF()
        else:
            data = self.getRDFMetadata()
        # Remove the XML header
        index = find(data, '\n')
        if (index > -1):
            data = data[index + 1:]
        return data

    def getRDFMetadata(self):
        """ Write metadata fields as RDF. """
        rdf_node = self._createNode(self.document, 'rdf:RDF',
                       attrs=[('xmlns:rdf', 'http://www.w3.org/1999/02/22-rdf-syntax-ns#'),
                              ('xmlns:dc', 'http://purl.org/dc/elements/1.1/'),
                              ('xmlns:dcterms', 'http://purl.org/dc/terms')])
        desc_node = self._createNode(rdf_node, 'rdf:Description',
                        attrs=[('rdf:about', self.context.renderBase())])
        self._writeDCMetadata(desc_node)
        return self.document.toprettyxml()        
                                

    def getCCLicenseRDF(self):
        """ Write into RDF CC License elements. """

        holder, license = self.clutil.getLicenseAndHolderFromObject(self.context)
        licenseId = ''
        if len(self.license) >= 3:
            lid = urlsplit(self.license[2])
            if len(lid) >= 3:
                lid = lid[2].split('/')
                if len(lid) >= 3:
                    licenseId = lid[2]

        if licenseId and self.clutil.hasCCLicenseInfo(licenseId):
            cc_rdf = self.clutil.getCCLicenseInfo(licenseId)
        
            rdf_node = self._createNode(self.document, 'rdf:RDF',
                           attrs=[('xmlns', 'http://creativecommons.org/ns#'),
                                  ('xmlns:dc', 'http://purl.org.dc/elements/1.1/'),
                                  ('xmlns:rdf', 'http://www.w3.org/1999/02/22-rdf-syntax-ns#')])
            work_node = self._createNode(rdf_node, 'Work', attrs=[('rdf:about',
                                                                   self.context.renderBase())])
            self._writeDCMetadata(work_node)
            self._createNode(work_node, 'license', attrs=[('rdf:resource', self.license[2])])
            return self.document.toprettyxml()
        else:
            return ''

    def _writeDCMetadata(self, node):
        """ Write the dublin core metadata in RDF. """

        # Identifier
        self._createNode(node, 'dc:identifier', self.context.renderBase())

        # Title
        self._createNode(node, 'dc:title', self.context.title )

        # Language
        lang = self.context.Language()
        if not lang:
            po = self.context.portal_url.getPortalObject()
            lang = po.portal_properties.site_properties.getProperty('default_language')
        self._createNode(node, 'dc:language', lang )

        # Description
        desc = self.context.Description()
        if desc:
            self._createNode(node, 'dc:description', self.context.Description() )

        # Subject
        self._renderList(node, 'dc:subject', [sub for sub in self.context.Subject() ] )

        # Type
        self._createNode(node, 'dc:type', self.context.Type())

        # Creators
        self._renderList(node, 'dc:creator', [creat for creat in self.context.Creators() ] )

        # Contributors
        self._renderList(node, 'dc:contributor', [contrib for contrib in self.context.Contributors() ] )

        # Publisher
        self._createNode(node, 'dc:publisher', self.context.portal_url.getPortalObject().Publisher() )

        # Format
        self._createNode(node, 'dc:format', self.context.Format())

        # Rights
        rights = self.context.Rights()
        if not rights:
            rights = self.props.DefaultSiteCopyright
        self._createNode(node, 'dc:rights', rights)

    def _renderList(self, node, element, value):
        """ Render a list of items in RDF. """
        if value:
            if len(value) > 1:
                value_node = self._createNode(node, element)
                bag_node = self._createNode(value_node, 'rdf:Bag')
                for x in value:
                    self._createNode(bag_node, 'rdf:li', x )
            else:
                self._createNode(node, element, value[0] )
        

    def _createNode(self, parent, ename, value=None, attrs=None):
        """ Create a node in the document. """
        newNode = self.document.createElement(ename)
        parent.appendChild(newNode)
        if value:
            newNode.appendChild(self.document.createTextNode(unicode_sanitize(value) ) )
        if attrs:
            for x in attrs:
                newNode.setAttribute(x[0], x[1] )
        return newNode

class RSSView:
    """ Implements base view functionality. """

    def __init__(self, context, request):
        self.context = context
        self.request = request
        self.cclicenses = {}
        self.props = context.portal_url.portal_properties.content_licensing_properties
        self.clutil = getUtility(IContentLicensingUtility)

    def getRSSObjects(self):
        """ Get objects for RSS. """
        syn = self.context.portal_syndication
        return list(syn.getSyndicatableContent(self.context))

    def getCCLicense(self, obj):
        """ Get License information """
        holder = self.props.DefaultSiteCopyrightHolder
        license = self.props.DefaultSiteLicense
        if obj != self.context.portal_url.getPortalObject():
            result = self.clutil.getLicenseAndHolderFromObject(obj)
            if result:
                if result[0] != '(site default)':
                    holder = license[0]
                if result[1][0] != 'Site Default':
                    license = result[1]
        if license and 'Creative Commons License' == license[0]:
            if not self.cclicenses.has_key(license[2]):
                self.cclicenses[license[2]] = license[1].split(' ')[0]
            return license[2], holder
        else:
            return None

    def getCCLicenseTags(self):
        """ Get the list of CC Licenses listed in the RSS Feed. """
        return [(self.cclicenses[x],x) for x in self.cclicenses]

    def getCCLicenseTag(self, cclicense, tag):
        """ Get appropriate cc license entries for the license tag. """
        if self.clutil.hasCCLicenseInfo(cclicense):
            license = self.clutil.getCCLicenseInfo(cclicense)
            if license.has_key(tag):
                return license[tag]
        return []
    
class PrefsView:
    """ prefs view """
    def __init__(self, context, request):
        self.context = context
        self.request = request
        self.props = context.portal_url.portal_properties.content_licensing_properties
        self.clutil = getUtility(IContentLicensingUtility)

    def getDefaultSiteLicense(self):
        """ Get the default site license """
        return self.props.DefaultSiteLicense

    def getDefaultSiteLicenseName(self):
        """ Get the default site license ID """
        return self.props.DefaultSiteLicense[0]

    def getLicenseById(self, id):
        """ Get a license by its id """
        return self.props.getProperty(id)

    def listSupportedJurisdictions(self):
        """ Return the list of supported jurisdictions """
        return self.clutil.listSupportedJurisdictions(self.context)

    def getJurisdiction(self):
        """ Return the current jurisdiction code """
        Jurisdiction = self.props.Jurisdiction
        if Jurisdiction == 'Unported':
           Jurisdiction = '' 
        return Jurisdiction

    def getDefaultSiteCopyright(self):
        """ Get the default site copyright string """
        return self.props.DefaultSiteCopyright

    def getDefaultSiteCopyrightHolder(self):
        """ Get the default site copyright holder """
        return self.props.DefaultSiteCopyrightHolder

    def getSupportedLicenses(self):
        """ Get the supported licenses """
        return self.props.SupportedLicenses

    def getAvailableLicenses(self):
        """ Get the available supported licenses """
        return self.props.AvailableLicenses

    def isAvailableLicense(self, id):
        """ Is this license available """
        return id in self.props.AvailableLicenses


    
    



from Products.CMFPlone.tests import PloneTestCase
from unittest import TestSuite, makeSuite
from Testing import ZopeTestCase
from Testing.ZopeTestCase import user_name
from AccessControl import Unauthorized
from base import ContentLicensingTestCase
from zope.component import getUtility
from zope.event import notify
from zope.lifecycleevent import ObjectModifiedEvent
from collective.contentlicensing.utilities.interfaces import IContentLicensingUtility


class TestContentLicensing(ContentLicensingTestCase):

    def afterSetUp(self):
        self.props = self.portal.portal_properties.content_licensing_properties
        self.clutil = getUtility(IContentLicensingUtility)

    def testRecursive(self):
        self.setRoles(['Manager'])
        # Create a folder
        self.portal.invokeFactory('Folder','folder1')
        folder1 = getattr(self.portal,'folder1')
        folder1.setTitle('Test Folder 01')
        # Create a document
        folder1.invokeFactory('Document','doc1')
        doc1 = getattr(folder1,'doc1')
        doc1.setTitle('Test Document 01')
        doc1.setCreators('Piotr Tchaikovsky\nWinter Daydreams\nLon Pathetique\nGuido Van Rossum')
        doc1.setText('lorem ipsum blah blah blah')
        # Create an image
        folder1.invokeFactory('Image','img1')
        img1 = getattr(folder1,'img1')
        img1.setTitle('Test Image 01')
        # Get GNU License and stuff it in the Request object
        gnu_license = self.props.getProperty('license_gnuFree')
        folder1.REQUEST['license'] = gnu_license[0]
        folder1.REQUEST['license_cc_name'] = gnu_license[1]
        folder1.REQUEST['recurse_cc_url'] = gnu_license[2]
        folder1.REQUEST['recurse_cc_button'] = gnu_license[3]
        folder1.REQUEST['recurse_folders'] = True
        # Fire off the request
        notify(ObjectModifiedEvent(folder1))
        # Check that it worked
        self.assertEqual(self.clutil.getLicenseAndHolderFromObject(folder1)[1][0],
                         'GNU Free Documentation License')
        self.assertEqual(self.clutil.getLicenseAndHolderFromObject(folder1)[1],
                         self.clutil.getLicenseAndHolderFromObject(doc1)[1])
        self.assertEqual(self.clutil.getLicenseAndHolderFromObject(folder1)[1],
                         self.clutil.getLicenseAndHolderFromObject(img1)[1])
        # Get all rights reserved license and stuff it in the request
        ar_license = self.props.getProperty('license_allRights')
        req = {}
        for x in folder1.REQUEST.keys():
            if x != 'recurse_folders':
                req[x] = folder1.REQUEST[x]
        folder1.REQUEST = req
        folder1.REQUEST['crazy_parameter'] = True
        # Fire off the request without the recurse option set
        notify(ObjectModifiedEvent(folder1))
        # Check that the doc and image have not changed
        self.assertEqual(self.clutil.getLicenseAndHolderFromObject(doc1)[1][0],
                         'GNU Free Documentation License')
        self.assertEqual(self.clutil.getLicenseAndHolderFromObject(img1)[1][0],
                         'GNU Free Documentation License')


def test_suite():
    suite = TestSuite()
    suite.addTest(makeSuite(TestContentLicensing))
    return suite





from zope.testing import doctest
from Products.PloneTestCase.PloneTestCase import setupPloneSite, installProduct
from Products.PloneTestCase.PloneTestCase import PloneTestCase, FunctionalTestCase
from setuptools import find_packages

from Products.Five import fiveconfigure
from Products.Five import zcml
from Testing import ZopeTestCase as ztc
from Products.PloneTestCase.layer import onsetup


packages=find_packages('src')
package_dir={'':'src'},

@onsetup
def setup_contentlicensing_project():
    """
    Load and install packages required for the collective.contentlicensing tests
    """

    fiveconfigure.debug_mode = True
    
    import collective.contentlicensing
    zcml.load_config('configure.zcml',collective.contentlicensing)
    
    fiveconfigure.debug_mode = False

    ztc.installPackage('collective.contentlicensing')


setup_contentlicensing_project()
setupPloneSite(with_default_memberarea=0,extension_profiles=['collective.contentlicensing:default'])

oflags = (doctest.ELLIPSIS |
          doctest.NORMALIZE_WHITESPACE)

prod = "collective.contentlicensing"

class ContentLicensingTestCase(PloneTestCase):
    """ Test Class """

    def _setupHomeFolder(self):
	""" Ugly hack to keep the underlying testing framework from trying to create a user folder."""
	pass


class ContentLicensingFunctionalTestCase(FunctionalTestCase):
    """ Functional test class """



##################################################################################
#    Copyright (C) 2006-2007 Utah State University, All rights reserved.          
#                                                                                 
#    This program is free software; you can redistribute it and/or modify         
#    it under the terms of the GNU General Public License as published by         
#    the Free Software Foundation; either version 2 of the License, or            
#    (at your option) any later version.                                          
#                                                                                 
#    This program is distributed in the hope that it will be useful,              
#    but WITHOUT ANY WARRANTY; without even the implied warranty of               
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                
#    GNU General Public License for more details.                                 
#                                                                                 
#    You should have received a copy of the GNU General Public License            
#    along with this program; if not, write to the Free Software                  
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA    
#                                                                                 
##################################################################################

__author__ = 'Brent Lambert, David Ray, Jon Thomas'
__docformat__ = 'restructuredtext'
__version__ = "$Revision: 1 $"[11:-2]


from zope.interface import Interface

class IContentLicensingUtility(Interface):
    """ Content Licensing Utility """

    def getLicenses(request):
        """ Return titles and ids for the supported licenses. """

    def getAvailableLicenses(request):
        """ Get available licenses. """

    def getLicenseByTitle(request, title):
        """ Return a license based on its title. """

    def getLicenseFromObject(self, obj):
        """ Get the copyright license for an object. """

    def getHolderFromObject(self, obj):
        """ Get the copyright holder for an object. """

    def getLicenseAndHolderFromObject(obj):
        """ Get the copyright holder and license from an object. """

    def setLicense(obj, license):
        """ Set a license using the Dublin Core Annotations interface. """

    def getDefaultSiteLicense(self, request):
        """ Get the default site license """

    def getSiteDefaultLicenseByLine(request):
        """ Get the site default for a copyright byline. """

    def isLicensable(obj):
        """ Is an object licensable? """

    def setRightsLicense(obj, newLicense):
        """ Set the Dublin Core Extension field. """

    def setRightsHolder(obj, holder):
        """ Set the Dublin Core Extension RighsHolder field. """

    def listSupportedJurisdictions(request):
        """ Return a list of supported jurisdiction codes. """

    def getJurisdictionCode(request):
        """ Return the current jurisdiction code. """



from Products.CMFPlone.tests import PloneTestCase
from unittest import TestSuite, makeSuite
from Testing import ZopeTestCase
from Testing.ZopeTestCase import user_name
from AccessControl import Unauthorized
from base import ContentLicensingTestCase


class testContentLicensing(ContentLicensingTestCase):
    
    def testThreeAuthorCitation(self):
        from collective.contentlicensing.browser import CopyrightBylineView
        self.setRoles(['Manager'])
        self.portal.invokeFactory('Document','doc1')
        doc1 = getattr(self.portal,'doc1')
        doc1.setTitle('Test Course 04')
        doc1.setCreators('Piotr Tchaikovsky\nWinter Daydreams\nLon Pathetique\nGuido Van Rossum')
        view = CopyrightBylineView(doc1,self.app.REQUEST)
        info = view.getCitationInfo()
        assert (info.find('Tchaikovsky, P., Daydreams, W., Pathetique, L., Rossum, G. V. (') == 0)
        assert (info.find('Test Course 04') > -1)
        assert (info.find('http://nohost/plone/doc1') > -1)
        
    def testNoAuthorCitation(self):
        from collective.contentlicensing.browser import CopyrightBylineView
        self.setRoles(['Manager'])
        self.portal.invokeFactory('Document','doc1')
        doc1 = getattr(self.portal,'doc1')
        doc1.setTitle('Test Course 04')
        doc1.setCreators('')
        view = CopyrightBylineView(doc1,self.app.REQUEST)
        info = view.getCitationInfo()
        assert (info.find('Test Course 04. (') == 0)
        assert (info.find('http://nohost/plone/doc1') > -1)
        assert (info.find('). Retrieved') > -1)
        
    def testOneAuthorCitation(self):
        from collective.contentlicensing.browser import CopyrightBylineView
        self.setRoles(['Manager'])
        self.portal.invokeFactory('Document','doc1')
        doc1 = getattr(self.portal,'doc1')
        doc1.setTitle('Test Course 04')
        doc1.setCreators('Guido Van Rossum')
        view = CopyrightBylineView(doc1,self.app.REQUEST)
        info = view.getCitationInfo()
        assert (info.find('Rossum, G. V. (') == 0)
        assert (info.find('Test Course 04') > -1)
        assert (info.find('http://nohost/plone/doc1') > -1)
        
    def testOneNameAuthorCitation(self):
        from collective.contentlicensing.browser import CopyrightBylineView
        self.setRoles(['Manager'])
        self.portal.invokeFactory('Document','doc1')
        doc1 = getattr(self.portal,'doc1')
        doc1.setTitle('Test Course 04')
        doc1.setCreators('Rossum')
        view = CopyrightBylineView(doc1,self.app.REQUEST)
        info = view.getCitationInfo()
        assert (info.find('Rossum. (') == 0)
        assert (info.find('Test Course 04') > -1)
        assert (info.find('http://nohost/plone/doc1') > -1)
        

def test_suite():
    suite = TestSuite()
    suite.addTest(makeSuite(testContentLicensing))
    return suite




from base import prod, oflags, ContentLicensingFunctionalTestCase
from Testing.ZopeTestCase import FunctionalDocFileSuite
from unittest import TestSuite


def test_suite():
    suite = TestSuite()

    prefstest = FunctionalDocFileSuite('tests/prefs.txt',
                                       package=prod,
                                       test_class=ContentLicensingFunctionalTestCase,
                                       optionflags=oflags)
    prefstest = FunctionalDocFileSuite('tests/browse.txt',
                                       package=prod,
                                       test_class=ContentLicensingFunctionalTestCase,
                                       optionflags=oflags)
                                                         
    suite.addTests((prefstest,))

    return suite



##################################################################################
#    Copyright (C) 2004-2007 Utah State University, All rights reserved.          
#                                                                                 
#    This program is free software; you can redistribute it and/or modify         
#    it under the terms of the GNU General Public License as published by         
#    the Free Software Foundation; either version 2 of the License, or            
#    (at your option) any later version.                                          
#                                                                                 
#    This program is distributed in the hope that it will be useful,              
#    but WITHOUT ANY WARRANTY; without even the implied warranty of               
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                
#    GNU General Public License for more details.                                 
#                                                                                 
#    You should have received a copy of the GNU General Public License            
#    along with this program; if not, write to the Free Software                  
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA    
#                                                                                 
##################################################################################

__author__ = 'Brent Lambert, David Ray, Jon Thomas'
__docformat__ = 'restructuredtext'
__version__ = "$Revision: 1 $"[11:-2]

from zope.component import getUtility
from collective.contentlicensing.utilities.interfaces import IContentLicensingUtility


def recursive_license(obj, evt):
    if not getattr(obj, 'REQUEST', None) or not obj.REQUEST.has_key('recurse_folders'):
        return
    #Recursively Licenses objects
    clutil = getUtility(IContentLicensingUtility)
    brains = obj.portal_catalog.searchResults(path={'query':('/'.join(obj.getPhysicalPath())+'/'), })
    for brain in brains:
        object = brain.getObject()
        if clutil.isLicensable(object):
            clutil.setObjLicense(object)
    



from Products.CMFPlone.tests import PloneTestCase
from unittest import TestSuite, makeSuite
from Testing import ZopeTestCase
from Testing.ZopeTestCase import user_name
from AccessControl import Unauthorized
from collective.contentlicensing.DublinCoreExtensions.interfaces import ILicensable, ILicense
from base import ContentLicensingTestCase
from zope.component import getUtility
from collective.contentlicensing.utilities.interfaces import IContentLicensingUtility

class TestContentLicensing(ContentLicensingTestCase):

    def afterSetUp(self):
        self.clutil = getUtility(IContentLicensingUtility)
        self.props = self.portal.portal_properties.content_licensing_properties

    def testContentLicensingInstall(self):
        # Test that there are 5 default licenses
        self.assertEqual(len(self.clutil.getLicenses(self.portal)), 5)

    def testFrontPage(self):
        frontpage = self.portal.restrictedTraverse('front-page')
        # Test that the front page is licensable
        self.failUnless(self.clutil.isLicensable(frontpage))
        # Test the default ByLine
        byline = self.clutil.getSiteDefaultLicenseByLine(frontpage)
        self.assertEqual(len(byline), 5)
        # Test that the front page has CC RDF when set to CC License
        
        # Test this with a functional test instead
        #temp_license = self.props.getProperty('license_cc')
        #self.clutil.manage_changeProperties(DefaultSiteLicense=temp_license)
        #self.failUnless('<license' in frontpage.view())
    
    def testGettingAndSettingLicenses(self):
        # Create a default document object
        self.setRoles(['Manager'])
        self.portal.invokeFactory('Folder','test-folder')
        self.folder = getattr(self.portal,'test-folder')
        self.folder.invokeFactory('Document', 'testDoc')
        test_doc = self.folder.testDoc

        # Check that the default license for the document is 'Site Default'
        self.assertEqual(self.clutil.getLicenseAndHolderFromObject(test_doc)[1][0],
                         'Site Default')
        # Test setting the license to other
        other_license = ['Other', 'MyLicense', 'None', 'None']
        self.clutil.setRightsLicense(test_doc, other_license)
        self.assertEqual(self.clutil.getLicenseAndHolderFromObject(test_doc)[1][0],
                         'Other')
        # Test setting the rights holder
        self.clutil.setRightsHolder(test_doc, 'David Ray')
        self.assertEqual(self.clutil.getLicenseAndHolderFromObject(test_doc)[0],
                         'David Ray')

def test_suite():
    suite = TestSuite()
    suite.addTest(makeSuite(TestContentLicensing))
    return suite




##################################################################################
#    Copyright (C) 2004-2007 Utah State University, All rights reserved.          
#                                                                                 
#    This program is free software; you can redistribute it and/or modify         
#    it under the terms of the GNU General Public License as published by         
#    the Free Software Foundation; either version 2 of the License, or            
#    (at your option) any later version.                                          
#                                                                                 
#    This program is distributed in the hope that it will be useful,              
#    but WITHOUT ANY WARRANTY; without even the implied warranty of               
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                
#    GNU General Public License for more details.                                 
#                                                                                 
#    You should have received a copy of the GNU General Public License            
#    along with this program; if not, write to the Free Software                  
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA    
#                                                                                 
##################################################################################

__author__ = 'Brent Lambert, David Ray, Jon Thomas'
__docformat__ = 'restructuredtext'
__version__ = "$Revision: 1 $"[11:-2]

from zope.interface import Interface, implements 
from zope.component import adapts, getMultiAdapter, getUtility
from zope.formlib import form
from zope.schema import TextLine, Choice, Tuple, Field
from zope.schema.vocabulary import SimpleVocabulary
from Products.CMFDefault.formlib.schema import SchemaAdapterBase
from Products.CMFPlone.interfaces import IPloneSiteRoot
from Products.CMFPlone.utils import getToolByName
from collective.contentlicensing import ContentLicensingMessageFactory as _
from Products.CMFCore.interfaces import IPropertiesTool, IMetadataTool
from plone.app.controlpanel.form import ControlPanelForm
from plone.fieldsets import FormFieldsets
from plone.app.form.validators import null_validator
from widgets import LicenseWidget
from plone.app.controlpanel.widgets import MultiCheckBoxVocabularyWidget 


def jurisdictionvocab(context):
    props = getToolByName(context, 'portal_properties')
    juris = props.content_licensing_properties.jurisdiction_options
    return SimpleVocabulary.fromItems([x.split(',') for x in juris])


def supportedvocab(context):
    props = getToolByName(context, 'portal_properties')
    supp = props.content_licensing_properties.AvailableLicenses
    ts = getToolByName(context.context,'translation_service')
    licenses = []
    for x in supp:
        value = getattr(props.content_licensing_properties, x)[0], x
        if 'Creative Commons License' == value[0]:
            value = (_(u'Creative Commons License Picker'), x)
	value = ts.translate(value[0]), value[1]
        licenses.append(value)
    return SimpleVocabulary.fromItems(licenses)


def defaultlicensevocab(context):
    props = getToolByName(context, 'portal_properties')
    supp = props.content_licensing_properties.SupportedLicenses
    ts = getToolByName(context.context,'translation_service')
    licenses = []
    for x in supp:
        value = getattr(props.content_licensing_properties, x)[0]
        licenses.append((ts.translate(value), value))
    return SimpleVocabulary.fromItems(licenses)

        
class IContentLicensingSettingsForm(Interface):    
    """ The view for content licensing prefs form. """

    jurisdiction = Choice(title=_(u'Jurisdiction'),
                          description=_(u'Specify the jurisdiction in which the content license '
                                        'is valid. (Any Jurisdiction changes must be saved before '
                                        'choosing a new Creative Commons license.)'),
                          required=True,
                          default='unported',
                          vocabulary='contentlicensing.jurisdictionvocab')

    publisher = TextLine(title=_(u'Publisher'),
                         description=_(u'The institution or individual responsible for publishing '
                                       'content in this portal.'),
                         required=False)
    default_copyright = TextLine(title=_(u'Default Copyright'),
                                 description=_(u'The default copyright to be used with content '
                                               'in this portal.'),
                                 required=False)

    default_copyright_holder = TextLine(title=_(u'Default Copyright Holder'),
                                        description=_(u'The default copyright owner for content in '
                                                      'this portal.'),
                                        required=False,)

    default_license = Choice(title=_(u'Default License'),
                             description=_(u'Default License'),
                             required=True,
                             vocabulary='contentlicensing.defaultlicensevocab')

    supported_licenses = Tuple(title=_(u'Supported Licenses'),
                               description=_(u'Choose the licenses which can be selected for individual '
                                             'objects. The Creative Commons License Picker provides an '
                                             'interactive form to choose an appropriate Creative '
                                             'Commons license.'),
                               required=True,
                               missing_value=tuple(),
                               value_type=Choice(vocabulary='contentlicensing.supportedvocab'))


class IContentLicensingNewLicenseForm(Interface):
    """ The view for the add new license form """
    new_license_name = TextLine(title=_(u'License Name'),
                                description=_(u'The name of the license.'),
                                required=False)

    new_license_url = TextLine(title=_(u'License Location'),
                               description=_(u'The URL pointer to information about the license.'),
                               required=False)

    new_license_icon = TextLine(title=_(u'License Icon'),
                                description=_(u'The URL pointer to an image associated with the license.'),
                                required=False)
                                           

class IContentLicensingPrefsForm(IContentLicensingSettingsForm, IContentLicensingNewLicenseForm):
    """ Combined settings and new license form. """


class ContentLicensingControlPanelAdapter(SchemaAdapterBase):
    """ Control Panel adapter """

    adapts(IPloneSiteRoot)
    implements(IContentLicensingPrefsForm)
    
    temp_license = ['', '', '', '']

    def __init__(self, context):
        super(ContentLicensingControlPanelAdapter, self).__init__(context)
        pprop = getUtility(IPropertiesTool)
        self.clprops = pprop.content_licensing_properties
        self.mdtool = getUtility(IMetadataTool)

    def get_jurisdiction(self):
        return self.clprops.Jurisdiction

    def set_jurisdiction(self, juris):
        self.clprops.Jurisdiction = juris

    def get_publisher(self):
        return self.mdtool.Publisher()

    def set_publisher(self, publisher):
        self.mdtool.editProperties(publisher=publisher)
    
    def get_default_copyright(self):
        return self.clprops.getProperty('DefaultSiteCopyright')

    def set_default_copyright(self, copyright):
        self.clprops.DefaultSiteCopyright = copyright

    def get_default_copyright_holder(self):
        return self.clprops.getProperty('DefaultSiteCopyrightHolder')
    
    def set_default_copyright_holder(self, holder):
        self.clprops.DefaultSiteCopyrightHolder = holder

    def get_default_license(self):
        return self.clprops.getProperty('DefaultSiteLicense')[0]

    def set_default_license(self, license_name):
        licenses = self.clprops.getProperty('AvailableLicenses')
        for x in licenses:
            license = getattr(self.clprops, x, None)
            if license and license[0] == license_name:
                self.clprops.DefaultSiteLicense = license
                break

    def get_supported_licenses(self):
        return self.clprops.SupportedLicenses

    def set_supported_licenses(self, licenses):
        self.clprops.SupportedLicenses = licenses

    def getCCLicense(self):
        return self.clprops.license_cc
    
    def setCCLicense(self, subname, url, icon):
        self.clprops.license_cc = ('Creative Commons License',
                                   subname,                                  
                                   url,
                                   icon)
        self.clprops.DefaultSiteLicense = ('Creative Commons License',
                                           subname,                                  
                                           url,
                                           icon) 

    
    jurisdiction = property(get_jurisdiction, set_jurisdiction)
    publisher = property(get_publisher, set_publisher)
    default_copyright = property(get_default_copyright, 
                                 set_default_copyright)
    default_copyright_holder = property(get_default_copyright_holder,
                                        set_default_copyright_holder)
    default_license = property(get_default_license,
                               set_default_license)
    supported_licenses = property(get_supported_licenses, 
                                  set_supported_licenses)


    # Use the new license fields to generate a new license, not set individual properties

    def get_nothing(self):
        return ''

    def set_nothing(self, param):
        pass

    new_license_name = property(get_nothing, set_nothing)
    new_license_url = property(get_nothing, set_nothing)
    new_license_icon = property(get_nothing, set_nothing)

    def setNewLicense(self, name, url, icon):
        """ Set a new license """
        new_license = [name, name, '', '']
        if url:
            new_license[2] = url
        if icon:
            new_license[3] = icon
        license_id = 'license_%s' %(''.join(name.lower().split()))
        self.clprops.manage_addProperty(license_id, new_license, 'lines')
        self.clprops.manage_changeProperties(SupportedLicenses=list(self.clprops.getProperty('SupportedLicenses')) + [license_id])
        self.clprops.manage_changeProperties(AvailableLicenses=list(self.clprops.getProperty('AvailableLicenses')) + [license_id])


settingsset = FormFieldsets(IContentLicensingSettingsForm)
settingsset.id = 'contentlicensingsettings'
settingsset.label = _(u'Content License Settings')

newlicenseset = FormFieldsets(IContentLicensingNewLicenseForm)
newlicenseset.id = 'contentlicensenewlicense'
newlicenseset.label = _(u'New License')


class ContentLicensingPrefsForm(ControlPanelForm):
    """ The view class for the content licensing preferences form. """

    implements(IContentLicensingPrefsForm)
    form_fields = FormFieldsets(settingsset, newlicenseset)
    form_fields['default_license'].custom_widget = LicenseWidget
    form_fields['supported_licenses'].custom_widget = MultiCheckBoxVocabularyWidget

    label = _(u'Content Licensing Settings')
    description = _(u'Configure site wide settings for copyright licensing '
                    'of content within this portal.')
    form_name = _(u'Content Licensing Settings')


    @form.action(_(u'Save'), name=u'save')
    def handle_edit_action(self, action, data):
        # If the CC license option has been chosen, copy the new fields
        # into the license
        if 'Creative Commons License' == data['default_license']:
            ad = self.adapters[IContentLicensingSettingsForm]
            # Get the hidden field data from the view in the form
            ad.setCCLicense(self.request['license_cc_name'],
                            self.request['license_cc_url'],
                            self.request['license_cc_button'])

        # Apply form changes        
        if form.applyChanges(self.context, self.form_fields, data, self.adapters):

            # If there is a new license in the form, add it to the properties page
            if data.has_key('new_license_name') and data['new_license_name']:
                ad = self.adapters[IContentLicensingNewLicenseForm]
                ad.setNewLicense(data['new_license_name'], 
                                 data['new_license_url'], 
                                 data['new_license_icon'])

            self.status = _("Changes saved.")
            self._on_save(data)
            self.request['fieldset.current'] = u'fieldsetlegend-contentlicensingsettings'
        else:
            self.status = _("No changes made.")
            
        



from zope.interface import Interface
from zope.schema import TextLine
from zope.publisher.interfaces.browser import IDefaultBrowserLayer

class IATTopic(Interface):
    pass

class IPortalObject(Interface):
    pass

class IContentLicensingLayer(IDefaultBrowserLayer):
    """ A layer specific to this product
    """



##################################################################################
#    Copyright (C) 2004-2007 Utah State University, All rights reserved.          
#                                                                                 
#    This program is free software; you can redistribute it and/or modify         
#    it under the terms of the GNU General Public License as published by         
#    the Free Software Foundation; either version 2 of the License, or            
#    (at your option) any later version.                                          
#                                                                                 
#    This program is distributed in the hope that it will be useful,              
#    but WITHOUT ANY WARRANTY; without even the implied warranty of               
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                
#    GNU General Public License for more details.                                 
#                                                                                 
#    You should have received a copy of the GNU General Public License            
#    along with this program; if not, write to the Free Software                  
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA    
#                                                                                 
##################################################################################

__author__ = 'Brent Lambert, David Ray, Jon Thomas'
__docformat__ = 'restructuredtext'
__version__ = "$Revision: 1 $"[11:-2]

from zope.app.component.interfaces import ISite
from Products.Five.site.localsite import enableLocalSiteHook
from zope.app.component.hooks import setSite
from utilities.interfaces import IContentLicensingUtility
from utilities.utils import ContentLicensingUtility
from zope.component import getSiteManager


def importFinalSteps(context):
    site = context.getSite()
    setupUtilities(site)

def setupUtilities(site):
    """ Register a local utility """

    if not ISite.providedBy(site):
        enableLocalSiteHook(site)

    setSite(site)

    sm = getSiteManager()
    if not sm.queryUtility(IContentLicensingUtility):
        sm.registerUtility(ContentLicensingUtility('contentlicensing'),
                        IContentLicensingUtility)



from Products.CMFPlone.tests import PloneTestCase
from unittest import TestSuite, makeSuite
from Testing import ZopeTestCase
from Testing.ZopeTestCase import user_name
from AccessControl import Unauthorized
from base import ContentLicensingTestCase
from zope.component import getUtility
from zope.event import notify
from zope.lifecycleevent import ObjectModifiedEvent
from collective.contentlicensing.utilities.interfaces import IContentLicensingUtility


class TestContentLicensing(ContentLicensingTestCase):   

    def afterSetUp(self):
        self.props = self.portal.portal_properties.content_licensing_properties
        self.clutil = getUtility(IContentLicensingUtility)
    
    def testNonLicensableTopic(self):
        from collective.contentlicensing.browser import CopyrightBylineView
        self.setRoles(['Manager'])
        
        self.portal.invokeFactory('Folder','folder1')
        folder1 = getattr(self.portal,'folder1')
        folder1.setTitle('Test Folder 01')
        
        folder1.invokeFactory('Document','doc1')
        doc1 = getattr(folder1,'doc1')
        doc1.setTitle('Test Document 01')
        doc1.setCreators('Piotr Tchaikovsky\nWinter Daydreams\nLon Pathetique\nGuido Van Rossum')
        doc1.setText('lorem ipsum blah blah blah')
        
        folder1.invokeFactory('Topic','sf1')
        sf1 = getattr(folder1,'sf1')
        sf1.setTitle('Test Smart Folder 01')
        sf1.setDescription('This is a test Smart Folder')

        view = CopyrightBylineView(doc1, self.app.REQUEST)
        assert(view.getLicenseByline())

        view = CopyrightBylineView(doc1, self.app.REQUEST)
        self.assertRaises(TypeError, view.getLicenseByline())

        
    def testNonLicensableRecurse(self):
        from collective.contentlicensing.browser import CopyrightBylineView
        self.setRoles(['Manager'])

        self.portal.invokeFactory('Folder','folder1')
        folder1 = getattr(self.portal,'folder1')
        folder1.setTitle('Test Folder 01')
        
        folder1.invokeFactory('Document','doc1')
        doc1 = getattr(folder1,'doc1')
        doc1.setTitle('Test Document 01')
        doc1.setCreators('Piotr Tchaikovsky\nWinter Daydreams\nLon Pathetique\nGuido Van Rossum')
        doc1.setText('lorem ipsum blah blah blah')
        
        folder1.invokeFactory('Topic','sf1')
        sf1 = getattr(folder1,'sf1')
        sf1.setTitle('Test Smart Folder 01')
        sf1.setDescription('This is a test Smart Folder')

        gnu_license = self.props.getProperty('license_gnuFree')
        folder1.REQUEST['license'] = gnu_license[0]
        folder1.REQUEST['license_cc_name'] = gnu_license[1]
        folder1.REQUEST['recurse_cc_url'] = gnu_license[2]
        folder1.REQUEST['recurse_cc_button'] = gnu_license[3]
        folder1.REQUEST['recurse_folders'] = True
        notify(ObjectModifiedEvent(folder1))

        self.assertEqual(self.clutil.getLicenseAndHolderFromObject(doc1)[1][0],
                         'GNU Free Documentation License')
        
        
def test_suite():
    suite = TestSuite()
    suite.addTest(makeSuite(TestContentLicensing))
    return suite




##################################################################################
#
#    Copyright (C) 2006 Utah State University, All rights reserved.
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
##################################################################################

__author__  = '''Brent Lambert, David Ray, Jon Thomas'''
__docformat__ = 'plaintext'
__version__   = '$ Revision 0.0 $'[11:-2]


"""
The following is based on code found in the Plone OpenPlans
application, which is licensed under GNU General Public License. 
Kudos to those folk who have figured out how
to make Zope 3 annotations work in a Zope 2 world!
"""

from Products.Archetypes.BaseObject import BaseObject
from zope.lifecycleevent import ObjectModifiedEvent
from zope.event import notify


def notifyObjectModified(obj):
    notify(ObjectModifiedEvent(obj))

def addDispatcherToMethod(func, dispatch):
    def new_func(*args, **kwargs):
        obj = args[0]
        value = func(*args, **kwargs)
        dispatch(obj)
        return value
    return new_func


BaseObject._processForm = addDispatcherToMethod(BaseObject._processForm,
                                                notifyObjectModified)

BaseObject.update = addDispatcherToMethod(BaseObject.update,
                                          notifyObjectModified)

BaseObject.edit = BaseObject.update
